/*
 * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
 *
 * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
 */

pub mod error;
pub mod method;
pub mod object;
pub mod references;
pub mod request;
pub mod response;
pub mod types;
